@@ -27,8 +27,8 @@
 // Include for providing source code compatibility
 #include <klocalizedstring.h>
 
-#include <QtCore/QString>
-#include <QtCore/QList>
+#include <QString>
+#include <QList>
 
 class QStringList;
 class QTextCodec;
@@ -65,6 +65,12 @@ class KLocalePrivate;
   * @author Stephan Kulow <coolo@kde.org>, Preston Brown <pbrown@kde.org>,
   * Hans Petter Bieker <bieker@kde.org>, Lukas Tinkl <lukas.tinkl@suse.cz>
   * @short class for supporting locale settings
+  *
+  * @deprecated since 5.0. For translation support use KLocalizedString (from the
+  * KI18n framework); for string formatting use QLocale() or KFormat (from the
+  * KCoreAddons framework) if QLocale doesn't provide the formatting you need.
+  * For more information about porting code that is still using KLocale see:
+  * https://community.kde.org/Frameworks/Porting_Notes#Localization
   */
 class KDELIBS4SUPPORT_EXPORT KLocale
 {
@@ -89,7 +95,7 @@ public:
      *                locale-related preferences (such as language, country,
      *                and formatting options).
      */
-    explicit KLocale(KSharedConfig::Ptr config = KSharedConfig::Ptr());
+    KDELIBS4SUPPORT_DEPRECATED explicit KLocale(KSharedConfig::Ptr config = KSharedConfig::Ptr());
 
     /**
      * Constructs a KLocale.
@@ -109,7 +115,7 @@ public:
      *                 and formatting options).
      */
     KLocale(const QString &language, const QString &country = QString(),
-            KConfig *config = 0);
+            KConfig *config = nullptr);
 
     /**
      * Copy constructor
@@ -629,7 +635,6 @@ public:
      */
     KDELIBS4SUPPORT_DEPRECATED bool nounDeclension() const;
 
-    //KDE5 move to KDateTime namespace
     /**
      * @since 4.6
      *
@@ -665,7 +670,6 @@ public:
         QDateCalendar = GregorianCalendar /**< @deprecated Alias for GregorianCalendar */
     };
 
-    //KDE5 move to KDateTime namespace
     /**
      * @since 4.6
      *
@@ -682,7 +686,6 @@ public:
         SimpleWeek        =  3  /**< Week 1 starts Jan 1st ends after 7 days */
     };
 
-    //KDE5 move to KDateTime namespace
     /**
      * @since 4.4
      *
@@ -694,7 +697,6 @@ public:
         UnicodeFormat     /**< UNICODE Standard (Qt/Java/OSX/Windows) */
     };
 
-    //KDE5 move to KDateTime namespace
     /**
      * @since 4.6
      *
@@ -712,7 +714,6 @@ public:
         //StrictParsing    /**< Parse Date/Time strictly to the format. */
     };
 
-    //KDE5 move to KDateTime namespace
     /**
      * @since 4.6
      *
@@ -758,7 +759,6 @@ public:
     };
     Q_DECLARE_FLAGS(DateTimeComponents, DateTimeComponent)
 
-    //KDE5 move to KDateTime namespace
     /**
      * @since 4.6
      *
@@ -777,7 +777,6 @@ public:
         LongName                     /**< Long text format, e.g. Monday for Monday */
     };
 
-    //KDE5 move to KDateTime namespace
     /**
      * Format for date string.
      */
@@ -795,7 +794,6 @@ public:
         IsoOrdinalDate    /**< ISO-8601 Ordinal Date format YYYY-DDD, e.g. 2009-001 */
     };
 
-    //KDE5 move to KDateTime namespace
     /**
      * Returns a string formatted to the current locale's conventions
      * regarding dates.
@@ -807,7 +805,6 @@ public:
      */
     QString formatDate(const QDate &date, DateFormat format = LongDate) const;
 
-    //KDE5 move to KDateTime namespace
     /**
      * Returns a string formatted to the current locale's conventions
      * regarding both date and time.
@@ -822,7 +819,6 @@ public:
     QString formatDateTime(const QDateTime &dateTime, DateFormat format = ShortDate,
                            bool includeSecs = false) const;
 
-    //KDE5 move to KDateTime namespace
     /**
      * Options for formatting date-time values.
      */
@@ -832,7 +828,6 @@ public:
     };
     Q_DECLARE_FLAGS(DateTimeFormatOptions, DateTimeFormatOption)
 
-    //KDE5 move to KDateTime namespace
     /**
      * Returns a string formatted to the current locale's conventions
      * regarding both date and time.
@@ -844,7 +839,7 @@ public:
      * @return The date and time as a string
      */
     QString formatDateTime(const KDateTime &dateTime, DateFormat format = ShortDate,
-                           DateTimeFormatOptions options = 0) const;
+                           DateTimeFormatOptions options = {}) const;
 
     /**
      * Use this to determine whether in dates a possessive form of month
@@ -870,7 +865,6 @@ public:
      */
     QString formatTime(const QTime &pTime, bool includeSecs = false, bool isDuration = false) const;
 
-    //KDE5 move to KDateTime namespace
     /**
      * @since 4.4
      *
@@ -897,7 +891,6 @@ public:
     };
     Q_DECLARE_FLAGS(TimeFormatOptions, TimeFormatOption)
 
-    //KDE5 move to KDateTime namespace
     /**
      * @since 4.4
      *
@@ -988,7 +981,6 @@ public:
      */
     const KCalendarSystem *calendar() const;
 
-    //KDE5 remove
     /**
      * @deprecated use calendarSystem() instead
      *
@@ -1011,7 +1003,6 @@ public:
      */
     KLocale::CalendarSystem calendarSystem() const;
 
-    //KDE5 remove
     /**
      * @deprecated use setCalendarSystem() instead
      *
@@ -1045,7 +1036,6 @@ public:
      */
     void setWeekNumberSystem(KLocale::WeekNumberSystem weekNumberSystem);
 
-    //KDE5 remove in favour of const version
     /**
      * @since 4.6
      *
@@ -1077,7 +1067,7 @@ public:
      *
      * @return The string converted to a double
      */
-    double readMoney(const QString &numStr, bool *ok = 0) const;
+    double readMoney(const QString &numStr, bool *ok = nullptr) const;
 
     /**
      * Converts a localized numeric string to a double.
@@ -1088,9 +1078,8 @@ public:
      *
      * @return The string converted to a double
      */
-    double readNumber(const QString &numStr, bool *ok = 0) const;
+    double readNumber(const QString &numStr, bool *ok = nullptr) const;
 
-    //KDE5 move to KDateTime namespace
     /**
      * Converts a localized date string to a QDate.  This method will try all
      * ReadDateFlag formats in preferred order to read a valid date.
@@ -1104,17 +1093,15 @@ public:
      * @return The string converted to a QDate
      * @see KCalendarSystem::readDate()
      */
-    QDate readDate(const QString &str, bool *ok = 0) const;
+    QDate readDate(const QString &str, bool *ok = nullptr) const;
 
-    //KDE5 move to KDateTime namespace
     /**
      * Converts a localized date string to a QDate, using the specified format.
      * You will usually not want to use this method.
      * @see KCalendarSystem::readDate()
      */
-    QDate readDate(const QString &intstr, const QString &fmt, bool *ok = 0) const;
+    QDate readDate(const QString &intstr, const QString &fmt, bool *ok = nullptr) const;
 
-    //KDE5 move to KDateTime namespace
     /**
      * Flags for readDate()
      */
@@ -1131,7 +1118,6 @@ public:
                                            ISO Week date format (YYYY-DDD) */
     };
 
-    //KDE5 move to KDateTime namespace
     /**
      * Converts a localized date string to a QDate.
      * This method is stricter than readDate(str,&ok): it will only accept
@@ -1145,7 +1131,7 @@ public:
      * @return The string converted to a QDate
      * @see KCalendarSystem::readDate()
      */
-    QDate readDate(const QString &str, ReadDateFlags flags, bool *ok = 0) const;
+    QDate readDate(const QString &str, ReadDateFlags flags, bool *ok = nullptr) const;
 
     /**
      * Converts a localized time string to a QTime.
@@ -1159,7 +1145,7 @@ public:
      *
      * @return The string converted to a QTime
      */
-    QTime readTime(const QString &str, bool *ok = 0) const;
+    QTime readTime(const QString &str, bool *ok = nullptr) const;
 
     /**
      * Flags for the old version of readTime()
@@ -1186,7 +1172,7 @@ public:
      *
      * @return The string converted to a QTime
      */
-    QTime readTime(const QString &str, ReadTimeFlags flags, bool *ok = 0) const;
+    QTime readTime(const QString &str, ReadTimeFlags flags, bool *ok = nullptr) const;
 
     /**
      * Additional processing options for readLocaleTime().
@@ -1222,7 +1208,7 @@ public:
      *
      * @return The string converted to a QTime
      */
-    QTime readLocaleTime(const QString &str, bool *ok = 0,
+    QTime readLocaleTime(const QString &str, bool *ok = nullptr,
                          TimeFormatOptions options = KLocale::TimeDefault,
                          TimeProcessingOptions processing = ProcessNonStrict) const;
 
